import doContent from './src/index.js'
import fs from 'fs';
import { dirname, resolve} from 'path';
import { fileURLToPath } from 'url';
const cache={}
function readFile(file) {
	if(!cache[file]) {
		let filename = file
		if(!filename.includes('/')) filename=`templates/${filename}`
		if(!filename.includes('.')) filename+='.yml'
		cache[file]=fs.readFileSync(resolve(dirname(fileURLToPath(import.meta.url)), filename),'utf8');
	}
	return cache[file]
}
function saveFile(file, yamlData) {
	if(!file.includes('.')) file+='.yml'
	fs.writeFileSync(resolve(dirname(fileURLToPath(import.meta.url)), 'output',file),yamlData, 'utf8')
}

async function run() {
	const files=fs.readdirSync(resolve(dirname(fileURLToPath(import.meta.url)), 'apps'))
	for(const file of files) {
		const yamlString = readFile(`apps/${file}`)
		await doContent(yamlString,readFile).then(parsed=>{
			saveFile(file, parsed)
		}).catch(error=>{
			console.error('error with',file,error)
			process.exit(1)
		})
	}
}
if(!process.argv[2]) run()
else {
	if(process.argv[2]=="-") process.argv[2]='/dev/stdin'
	const filenames=process.argv.slice(2)
	const content = filenames.map(file=>{
		if(!file.includes('.')) file+='.yml'
		return file
	}).map(file=>fs.readFileSync(file,'utf8').trim()).join('\n---\n').replaceAll('---\n---','---')
	doContent(content,readFile).then(parsed=>{
		console.log(parsed)
	}).catch(error=>{
		console.error('error!',error)
		process.exit(1)
	})
}
